@@ -1,16 +1,14 @@
 package Faker::Provider::PhoneNumber;
 
-use 5.14.0;
-use feature 'switch';
-use feature 'unicode_strings';
-use Moo;
-use Function::Parameters;
+use Bubblegum::Class;
+use Bubblegum::Syntax -types;
 
 with 'Faker::Role::Data';
 with 'Faker::Role::Provider';
 
 around guesser => sub {
-    my ($orig, $self, $format) = @_;
+    my ($orig, $self, $format) =
+        (shift, type_obj(shift), type_str(shift));
 
     given ($format) {
         when (/^(phonenumber|phone|telephone)$/) {
@@ -21,10 +19,11 @@ around guesser => sub {
     $self->$orig($format);
 };
 
-method phone_number {
-    my $data   = $self->data;
-    my $format = $self->random_item(@{$data->{phone_number_data_formats}});
-    $self->generator->parse($format);
+sub phone_number {
+    my $self   = type_obj shift;
+    my $data   = type_href $self->data;
+    my $format = $self->random_item($data->{phone_number_data_formats});
+    return $self->generator->parse($format);
 }
 
 1;
