@@ -1,34 +1,36 @@
 package Faker::Role::Provider;
 
-use 5.14.0;
-use feature 'switch';
-use feature 'unicode_strings';
+use Bubblegum::Role;
+use Bubblegum::Syntax -types, -typesof;
+
 use Faker::Generator::Null;
 use Faker::Generator::Unique;
-use Moo::Role;
-use Function::Parameters;
-use Types::Standard qw(InstanceOf);
 
 with 'Faker::Role::Utility';
 
 has generator => (
     is       => 'ro',
-    isa      => InstanceOf['Faker::Generator'],
+    isa      => typeof_obj,
     required => 1
 );
 
 has unique_generator => (
     is       => 'ro',
-    isa      => InstanceOf['Faker::Generator::Unique'],
+    isa      => typeof_obj,
     lazy     => 1,
     builder  => 1
 );
 
-method _build_unique_generator {
-    return Faker::Generator::Unique->new(generator => $self->generator);
+sub _build_unique_generator {
+    return Faker::Generator::Unique->new(
+        generator => shift->generator
+    );
 }
 
-method guesser ($format) {
+sub guesser {
+    my $self   = type_obj shift;
+    my $format = type_str shift;
+
     given ($format) {
         when (/^is_/) {
             return 'boolean';
@@ -36,12 +38,17 @@ method guesser ($format) {
     }
 }
 
-method optional ($weight=0.5) {
+sub optional {
+    my $self   = type_obj shift;
+    my $weight = type_num shift // 0.5;
     return $self->generator if rand(100) <= $weight * 100;
     return Faker::Generator::Null->new;
 }
 
-method unique ($reset=0, $retries=10000) {
+sub unique {
+    my $self    = type_obj shift;
+    my $reset   = type_num shift // 0;
+    my $retries = type_num shift // 10000;
     return $self->unique_generator if !$reset;
 
     my $ugen = Faker::Generator::Unique->new(max_retries => $retries);
